aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib/misc
diff options
context:
space:
mode:
authorJack Lloyd <[email protected]>2016-10-10 01:50:46 -0400
committerJack Lloyd <[email protected]>2016-10-10 01:50:46 -0400
commit227d59d886418ace13aa91c1b0dc5fea91efbb4a (patch)
treebdf9579874d66acac518ac53ce1ddcde6fb4d719 /src/lib/misc
parent35657e0f76931f0d3a333610e7065c81c35e9f1e (diff)
Add IncludeOS target. Make filesystem support optional.
Diffstat (limited to 'src/lib/misc')
-rw-r--r--src/lib/misc/srp6/srp6_files.cpp5
-rw-r--r--src/lib/misc/srp6/srp6_files.h7
2 files changed, 5 insertions, 7 deletions
diff --git a/src/lib/misc/srp6/srp6_files.cpp b/src/lib/misc/srp6/srp6_files.cpp
index 14ab1ac61..606c12ad7 100644
--- a/src/lib/misc/srp6/srp6_files.cpp
+++ b/src/lib/misc/srp6/srp6_files.cpp
@@ -8,14 +8,11 @@
#include <botan/srp6_files.h>
#include <botan/parsing.h>
#include <botan/base64.h>
-#include <fstream>
namespace Botan {
-SRP6_Authenticator_File::SRP6_Authenticator_File(const std::string& filename)
+SRP6_Authenticator_File::SRP6_Authenticator_File(std::istream& in)
{
- std::ifstream in(filename);
-
if(!in)
return; // no entries
diff --git a/src/lib/misc/srp6/srp6_files.h b/src/lib/misc/srp6/srp6_files.h
index 2b20de7a3..db128727e 100644
--- a/src/lib/misc/srp6/srp6_files.h
+++ b/src/lib/misc/srp6/srp6_files.h
@@ -9,6 +9,7 @@
#define BOTAN_SRP6A_FILES_H__
#include <botan/bigint.h>
+#include <iosfwd>
#include <string>
#include <map>
@@ -20,11 +21,11 @@ namespace Botan {
class BOTAN_DLL SRP6_Authenticator_File
{
public:
+
/**
* @param filename will be opened and processed as a SRP
* authenticator file
*/
- explicit SRP6_Authenticator_File(const std::string& filename);
+ explicit SRP6_Authenticator_File(std::istream& input);
bool lookup_user(const std::string& username,
BigInt& v,
@@ -20,11 +21,11 @@ namespace Botan {
/**
- * @param filename will be opened and processed as a SRP
- * authenticator file
+ * @param input will be read and processed as SRP authenticator file
*/